@@ -26,11 +26,9 @@ if sys.platform.startswith('win'):
     DYNAMIPS_DEFAULT_PATH = unicode('dynamips.exe')
 elif sys.platform.startswith('darwin'):
     if hasattr(sys, "frozen"):
-        DYNAMIPS_DEFAULT_PATH = os.getcwdu() + os.sep + '../Resources/dynamips-0.2.10-OSX.intel64.bin'
+        DYNAMIPS_DEFAULT_PATH = os.getcwdu() + os.sep + '../Resources/dynamips'
     else:
-        DYNAMIPS_DEFAULT_PATH = os.getcwdu() + os.sep + 'dynamips-0.2.10-OSX.intel64.bin'
-elif sys.platform.startswith('openbsd'):
-    DYNAMIPS_DEFAULT_PATH = unicode('/usr/local/bin/dynamips')
+        DYNAMIPS_DEFAULT_PATH = os.getcwdu() + os.sep + 'dynamips'
 else:
     DYNAMIPS_DEFAULT_PATH = unicode('dynamips')
 
@@ -57,8 +55,6 @@ if sys.platform.startswith('win'):
     QEMUWRAPPER_DEFAULT_PATH = unicode('qemuwrapper.exe')
 elif sys.platform.startswith('darwin') and hasattr(sys, "frozen"):
     QEMUWRAPPER_DEFAULT_PATH = os.getcwdu() + os.sep + '../Resources/qemuwrapper.py'
-elif sys.platform.startswith('openbsd'):
-    QEMUWRAPPER_DEFAULT_PATH = unicode('/usr/local/libexec/gns3/qemuwrapper.py')
 else:
     # look for qemuwrapper in the current working directory
     qemuwrapper_path = os.getcwdu() + os.sep + 'qemuwrapper/qemuwrapper.py'
@@ -90,20 +86,18 @@ elif sys.platform.startswith('darwin') and hasattr(sys, "frozen"):
         QEMU_DEFAULT_PATH = os.getcwdu() + os.sep + '../Resources/Qemu-0.11.0/bin/qemu'
         QEMU_IMG_DEFAULT_PATH = os.getcwdu() + os.sep + '../Resources/Qemu-0.11.0/bin/qemu-img'
 else:
-    QEMU_DEFAULT_PATH = unicode('/usr/local/bin/qemu-system-i386')
-    QEMU_IMG_DEFAULT_PATH = unicode('/usr/local/bin/qemu-img')
+    QEMU_IMG_DEFAULT_PATH = unicode('qemu-img')
+    QEMU_DEFAULT_PATH = unicode('qemu-i386')
 
 # Default path to vboxwrapper
 if sys.platform.startswith('win'):
     VBOXWRAPPER_DEFAULT_PATH = unicode('vboxwrapper.exe')
 elif sys.platform.startswith('darwin') and hasattr(sys, "frozen"):
     VBOXWRAPPER_DEFAULT_PATH = os.getcwdu() + os.sep + '../Resources/VBoxWrapper/Contents/MacOS/VBoxWrapper'
-elif sys.platform.startswith('openbsd'):
-    VBOXWRAPPER_DEFAULT_PATH = unicode('/usr/local/libexec/gns3/vboxwrapper.py')
 else:
     # look for vboxwrapper in the current working directory
     vboxwrapper_path = os.getcwdu() + os.sep + 'vboxwrapper/vboxwrapper.py'
-    if os.path.exists(vboxwrapper_path):
+    if os.path.exists(qemuwrapper_path):
         VBOXWRAPPER_DEFAULT_PATH = vboxwrapper_path
     elif platform.system() == 'Linux':
         VBOXWRAPPER_DEFAULT_PATH = unicode("/usr/share/gns3/vboxwrapper.py")
