@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# vim: expandtab ts=4 sw=4 sts=4:
+# vim: expandtab ts=4 sw=4 sts=4 fileencoding=utf-8:
 #
 # Copyright (C) 2007-2011 GNS3 Development Team (http://www.gns3.net/team).
 #
@@ -23,6 +22,7 @@ import os, sys, cmd, socket
 import GNS3.Globals as globals
 import GNS3.Dynagen.dynagen as Dynagen_Namespace
 import GNS3.Dynagen.dynamips_lib as lib
+import GNS3.Dynagen.portTracker_lib as tracker
 import GNS3.NETFile as netfile
 from PyQt4 import QtCore, QtGui
 from GNS3.Utils import translate
@@ -32,6 +32,7 @@ from GNS3.Node.IOSRouter import IOSRouter
 from GNS3.Node.AnyEmuDevice import AnyEmuDevice
 from GNS3.Node.AnyVBoxEmuDevice import AnyVBoxEmuDevice
 
+
 class Console(PyCutExt, Dynagen_Console):
 
     # list of keywords to color
@@ -58,18 +59,21 @@ class Console(PyCutExt, Dynagen_Console):
                     "suspend",
                     "telnet",
                     "vboxexec",
+                    "qmonitor",
                     "ver"])
 
     def __init__(self, parent):
         """ Initialise the Console widget
         """
 
+        from __main__ import VERSION
+
         # Set the prompt, for Dynagen.Console and PyCutExt
         self.prompt = '=> '
         sys.ps1 = '=> '
 
         # Set introduction message
-        self.intro = 'Dynagen management console for Dynamips (adapted for GNS3)\nCopyright (c) 2006-2012 GNS3 Project'
+        self.intro = "GNS3 management console. Running GNS3 version %s.\nCopyright (c) 2006-2013 GNS3 Project." % VERSION
 
         # Parent class initialisation
         try:
@@ -77,7 +81,7 @@ class Console(PyCutExt, Dynagen_Console):
             # put our own keywords list
             self.colorizer.keywords = self.keywords
             self._Dynagen_Console_init()
-        except Exception,e:
+        except Exception, e:
             sys.stderr.write(e.message)
 
     def _Dynagen_Console_init(self):
@@ -149,7 +153,7 @@ class Console(PyCutExt, Dynagen_Console):
             source = '\n'.join(self.lines)
             # Exec!
             self.more = self.onecmd(source)
-        except Exception,e:
+        except Exception, e:
             print e
 
         self.write(self.prompt)
@@ -164,7 +168,7 @@ class Console(PyCutExt, Dynagen_Console):
         from __main__ import VERSION, GNS3_RUN_PATH
 
         bitness = struct.calcsize("P") * 8
-        pythonver = str(sys.version_info[0])+'.'+str(sys.version_info[1])+'.'+str(sys.version_info[2])
+        pythonver = str(sys.version_info[0]) + '.' +str(sys.version_info[1])+'.'+str(sys.version_info[2])
         if hasattr(sys, "frozen"):
             print 'GNS3 version is ' + VERSION + " (compiled)"
         else:
@@ -178,7 +182,7 @@ class Console(PyCutExt, Dynagen_Console):
 
         try:
             Dynagen_Console.do_ver(self, args)
-        except Exception,e:
+        except Exception, e:
             print e
 
     def do_start(self, args):
@@ -193,9 +197,9 @@ class Console(PyCutExt, Dynagen_Console):
                     globals.GApp.mainWindow.treeWidget_TopologySummary.changeNodeStatus(node.hostname, 'running')
         except lib.DynamipsError, msg:
             QtGui.QMessageBox.critical(self, translate("Console", "%s: Dynamips error") % node.hostname,  unicode(msg))
-        except lib.DynamipsWarning,  msg:
+        except lib.DynamipsWarning, msg:
             QtGui.QMessageBox.warning(self, translate("Console", "%s: Dynamips warning") % node.hostname,  unicode(msg))
-        except (lib.DynamipsErrorHandled,  socket.error):
+        except (lib.DynamipsErrorHandled, socket.error):
             QtGui.QMessageBox.critical(self, translate("Console", "%s: Dynamips error") % node.hostname, translate("Console", "Connection lost"))
 
     def do_stop(self, args):
@@ -284,6 +288,22 @@ Example for Linux guest:
         except (lib.DynamipsErrorHandled,  socket.error):
             QtGui.QMessageBox.critical(self, translate("Console", "%s: Dynamips error") % node.hostname, translate("Console", "Connection lost"))
 
+    def do_qmonitor(self, args):
+        """qmonitor <QEMU device> <command>\nCommunicate with qemu monitor mode.\nDisplay available commands: qmonitor <QEMU device> help"""
+
+        if '?' in args or args.strip() == '':
+            print self.do_qmonitor.__doc__
+            return
+
+        try:
+            Dynagen_Console.do_qmonitor(self, args)
+        except lib.DynamipsError, msg:
+            QtGui.QMessageBox.critical(self, translate("Console", "Dynamips error"),  unicode(msg))
+        except lib.DynamipsWarning,  msg:
+            QtGui.QMessageBox.warning(self,  translate("Console", "Dynamips warning"),  unicode(msg))
+        except (lib.DynamipsErrorHandled,  socket.error):
+            QtGui.QMessageBox.critical(self, translate("Console", "Dynamips error"), translate("Console", "Connection lost"))
+
     def do_show(self, args):
         """show mac <ethernet_switch_name>
 \tshow the mac address table of an ethernet switch
@@ -299,6 +319,10 @@ show run <device_name>
 \tshow running configuration of a router
 show hypervisors
 \tshow allocated memory for hypervisors by Hypervisor Manager
+show ports
+\tshow all TCP ports allocated by GNS3
+show project_info
+\tshow the current project path
         """
 
         if '?' in args or args.strip() == '':
@@ -310,6 +334,41 @@ show hypervisors
         if command == 'hypervisors' and globals.GApp.HypervisorManager:
             globals.GApp.HypervisorManager.showHypervisors()
             return
+        elif command == 'ports':
+            track = tracker.portTracker()
+            track.showTcpPortAllocation()
+            return
+        elif command == 'project_info':
+            print
+            print "Project File:\t\t\t" + globals.GApp.mainWindow.projectFile
+            if globals.GApp.workspace.projectWorkdir:
+                print "Project Working directory:\t\t" + globals.GApp.workspace.projectWorkdir
+            print "Project Config directory:\t\t" + globals.GApp.workspace.projectConfigs
+            print
+
+            qemu_flash_drives_directory = os.path.dirname(globals.GApp.workspace.projectFile) + os.sep + 'qemu-flash-drives'
+            if os.access(qemu_flash_drives_directory, os.F_OK):
+                workdir = qemu_flash_drives_directory
+            elif globals.GApp.systconf['qemu'].qemuwrapper_workdir:
+                workdir = globals.GApp.systconf['qemu'].qemuwrapper_workdir
+            else:
+                realpath = os.path.realpath(self.dynagen.global_filename)
+                workdir = os.path.dirname(realpath)
+            print "Qemuwrapper working directory:\t" + workdir
+
+            if globals.GApp.systconf['vbox'].enable_VBoxManager:
+                if globals.GApp.workspace.projectWorkdir:
+                    workdir = globals.GApp.workspace.projectWorkdir
+                elif globals.GApp.systconf['vbox'].vboxwrapper_workdir:
+                    workdir = globals.GApp.systconf['vbox'].vboxwrapper_workdir
+                else:
+                    realpath = os.path.realpath(self.dynagen.global_filename)
+                    workdir = os.path.dirname(realpath)
+                print "Vboxwrapper working directory:\t" + workdir
+            else:
+                print "VBoxManager is disabled"
+
+            print "Dynamips working directory:\t\t" + globals.GApp.systconf['dynamips'].workdir
         else:
             Dynagen_Console.do_show(self, args)
 
@@ -334,7 +393,7 @@ Examples:
             if command == 'mac':
                 try:
                     Dynagen_Console.do_clear(self, args)
-                except Exception,e:
+                except Exception, e:
                     print e
         except ValueError:
             print translate("Console", "Incorrect number of paramaters or invalid parameters")
@@ -394,7 +453,7 @@ Examples:
                 device = params[0]
                 if command == 'get':
                     current_idlepc = self.dynagen.devices[device].idlepc
-                    if len(params) < 2 or params[1] != 'force' and current_idlepc != None:
+                    if (len(params) < 2 or params[1] != 'force') and current_idlepc:
                         print translate("Console", "%s already has an idlepc value applied (%s).") % (device, current_idlepc)
                         return
 
@@ -446,7 +505,7 @@ Examples:
                                 router = node.get_dynagen_device()
                                 if globals.GApp.iosimages.has_key(router.dynamips.host + ':' + router.image):
                                     image = globals.GApp.iosimages[router.dynamips.host + ':' + router.image]
-                                    image.idlepc =  idles[int(selection)]
+                                    image.idlepc = idles[int(selection)]
                     except:
                         print translate("Console", "Can't apply idlepc value")
             else:
@@ -543,7 +602,10 @@ Examples:
         net = netfile.NETFile()
         for device in devices:
             if isinstance(device, lib.Router):
-                net.export_router_config(device)
+                try:
+                    net.export_router_config(device)
+                except lib.DynamipsErrorHandled:
+                    continue
         globals.GApp.workspace.projectConfigs = save
 
     def do_import(self, args):
@@ -552,7 +614,7 @@ Examples:
         Dynagen_Console.do_import(self, args)
 
     def do_debug(self, args):
-        """debug [level]\nActivate/Desactivate debugs\nLevel 0: no debugs\nLevel 1: dynamips lib debugs only\nLevel 2: GNS3 debugs only\nLevel 3: GNS3 debugs and dynamips lib debugs"""
+        """debug [level]\nActivate/Deactivate debugs\nLevel 0: no debugs\nLevel 1: dynamips lib debugs only\nLevel 2: GNS3 debugs only\nLevel 3: GNS3 debugs and dynamips lib debugs"""
 
         if len(args) == 1:
             try:
@@ -560,10 +622,13 @@ Examples:
                 if level == 1 or level == 3:
                     globals.debugLevel = level
                     lib.setdebug(True)
+                    tracker.setdebug(True)
                 if level == 0 or level == 2:
                     globals.debugLevel = level
                     lib.setdebug(False)
+                    tracker.setdebug(False)
             except:
                 print self.do_debug.__doc__
         else:
             print self.do_debug.__doc__
+            print "Current debug level is %i" % globals.debugLevel
