@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# vim: expandtab ts=4 sw=4 sts=4:
+# vim: expandtab ts=4 sw=4 sts=4 fileencoding=utf-8:
 #
 # Copyright (C) 2007-2010 GNS3 Development Team (http://www.gns3.net/team).
 #
@@ -30,8 +29,11 @@ class AnyEmuDefaults(AbstractDefaults):
 
         self.default_image = 'None'
         self.default_netcard = 'rtl8139'
+        self.default_flavor = 'Default'
         self.default_nics = 6
+        self.default_usermod = False
         self.default_kvm = False
+        self.default_monitor = False
         self.default_options = ''
         self.default_ram = 256
         self.qemu = None
@@ -86,6 +88,14 @@ class JunOSDefaults(AnyEmuDefaults):
     def __init__(self):
         AnyEmuDefaults.__init__(self)
 
+class AWPDefaults(AnyEmuDefaults):
+    def __init__(self):
+        AnyEmuDefaults.__init__(self)
+        self.default_initrd = 'None'
+        self.default_kernel = 'None'
+        self.default_rel = 'None'
+        self.default_kernel_cmdline = 'None'
+
 class IDSDefaults(AnyEmuDefaults):
     def __init__(self):
         AnyEmuDefaults.__init__(self)
