@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# vim: expandtab ts=4 sw=4 sts=4:
+# vim: expandtab ts=4 sw=4 sts=4 fileencoding=utf-8:
 #
 # Copyright (C) 2007-2010 GNS3 Development Team (http://www.gns3.net/team).
 #
@@ -19,7 +18,7 @@
 # developers@gns3.net
 #
 
-# This file is for pylupdate4, to allow us to translate strings that we 
+# This file is for pylupdate4, to allow us to translate strings that we
 # use dynamically in GNS3 with Qtlinguist
 
 # Translation of the current language name
@@ -43,7 +42,10 @@ translate('nodesDock', 'ATM switch')
 translate('nodesDock', 'Frame Relay switch')
 translate('nodesDock', 'Cloud')
 translate('nodesDock', 'Decorative node')
+translate('nodesDock', 'EtherSwitch router')
 translate('nodesDock', 'Juniper router')
 translate('nodesDock', 'ASA firewall')
+translate('nodesDock', 'AW+ router')
 translate('nodesDock', 'IDS')
-translate('nodesDock', 'Qemu host')
+translate('nodesDock', 'Qemu guest')
+translate('nodesDock', 'VirtualBox guest')
