@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# vim: expandtab ts=4 sw=4 sts=4:
+# vim: expandtab ts=4 sw=4 sts=4 fileencoding=utf-8:
 #
 # Copyright (C) 2007-2010 GNS3 Development Team (http://www.gns3.net/team).
 #
@@ -108,7 +107,10 @@ class Cloud(AbstractNode):
                     info += " is connected to " + neighbor.hostname + " " + ifname
                 else:
                     info += " is not connected"
-            self.setToolTip(info)
+            try:
+                self.setToolTip(info)
+            except:
+                AbstractNode.setCustomToolTip(self)
         else:
             AbstractNode.setCustomToolTip(self)
 
@@ -163,9 +165,23 @@ class Cloud(AbstractNode):
             else:
                 interfaces = map(lambda interface: interface.name(), QtNetwork.QNetworkInterface.allInterfaces())
                 for interface in interfaces:
-                    nio = 'nio_gen_eth:' + str(interface)
+                    if str(interface).startswith("tap"):
+                        nio = 'nio_tap:' + str(interface)
+                    else:
+                        nio = 'nio_gen_eth:' + str(interface)
                     if not nio in self.config['nios']:
                         self.config['nios'].append(nio)
+
+            # adding NIO UDPs for VPCS
+            self.config['nios'].extend(['nio_udp:30000:127.0.0.1:20000',
+                                        'nio_udp:30001:127.0.0.1:20001',
+                                        'nio_udp:30002:127.0.0.1:20002',
+                                        'nio_udp:30003:127.0.0.1:20003',
+                                        'nio_udp:30004:127.0.0.1:20004',
+                                        'nio_udp:30005:127.0.0.1:20005',
+                                        'nio_udp:30006:127.0.0.1:20006',
+                                        'nio_udp:30007:127.0.0.1:20007',
+                                        'nio_udp:30008:127.0.0.1:20008'])
         return True
 
     def startNode(self):
