@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# vim: expandtab ts=4 sw=4 sts=4:
+# vim: expandtab ts=4 sw=4 sts=4 fileencoding=utf-8:
 #
 # Copyright (C) 2007-2010 GNS3 Development Team (http://www.gns3.net/team).
 #
@@ -71,7 +70,8 @@ class FRSW(AbstractNode):
         if self.frsw:
             try:
                 self.frsw.delete()
-                del self.dynagen.devices[self.hostname]
+                if self.dynagen.devices.has_key(self.hostname):
+                    del self.dynagen.devices[self.hostname]
                 if self.frsw in self.hypervisor.devices:
                     self.hypervisor.devices.remove(self.frsw)
                 self.dynagen.update_running_config()
@@ -92,7 +92,10 @@ class FRSW(AbstractNode):
         """
 
         if self.frsw:
-            self.setToolTip(self.frsw.info())
+            try:
+                self.setToolTip(self.frsw.info())
+            except:
+                AbstractNode.setCustomToolTip(self)
         else:
             AbstractNode.setCustomToolTip(self)
 
