@@ -29,21 +29,22 @@ class Page_ETHSW(QtGui.QWidget, Ui_ETHSWPage):
     """
 
     def __init__(self):
-    
+
         QtGui.QWidget.__init__(self)
         self.setupUi(self)
         self.setObjectName("ETHSW")
-        
+
         # connect slots
         self.connect(self.pushButtonAdd, QtCore.SIGNAL('clicked()'), self.slotAddPort)
         self.connect(self.pushButtonDelete, QtCore.SIGNAL('clicked()'), self.slotDeletePort)
         self.connect(self.treeWidgetPorts,  QtCore.SIGNAL('itemActivated(QTreeWidgetItem *, int)'),  self.slotPortselected)
         self.connect(self.treeWidgetPorts,  QtCore.SIGNAL('itemSelectionChanged()'),  self.slotPortSelectionChanged)
+        #self.connect(self.comboBoxPortType, QtCore.SIGNAL('currentIndexChanged(int)'), self.slotPortTypeChanged)
 
         # enable sorting
         self.treeWidgetPorts.sortByColumn(0, QtCore.Qt.AscendingOrder)
         self.treeWidgetPorts.setSortingEnabled(True)
-        
+
         self.ports = {}
         self.vlans= {}
 
@@ -59,7 +60,7 @@ class Page_ETHSW(QtGui.QWidget, Ui_ETHSWPage):
         index = self.comboBoxPortType.findText(type)
         if index != -1:
             self.comboBoxPortType.setCurrentIndex(index)
-        
+
     def slotPortSelectionChanged(self):
         """ Enable the use of the delete button
         """
@@ -69,15 +70,25 @@ class Page_ETHSW(QtGui.QWidget, Ui_ETHSWPage):
             self.pushButtonDelete.setEnabled(True)
         else:
             self.pushButtonDelete.setEnabled(False)
-        
+
+    def slotPortTypeChanged(self, index):
+        """ Gray out VLAN box when dot1q is selected
+        """
+
+        if index == 1:
+            # index 1 is dot1q
+            self.spinBoxVLAN.setEnabled(False)
+        else:
+            self.spinBoxVLAN.setEnabled(True)
+
     def slotAddPort(self):
         """ Add a new port
         """
-    
+
         port = self.spinBoxPort.value()
         vlan = self.spinBoxVLAN.value()
         type = str(self.comboBoxPortType.currentText())
-        
+
         if self.ports.has_key(port):
             # update vlan for a given port
 
@@ -97,16 +108,16 @@ class Page_ETHSW(QtGui.QWidget, Ui_ETHSWPage):
             item.setText(1, str(vlan))
             item.setText(2, type)
             self.treeWidgetPorts.addTopLevelItem(item)
-            
+
         self.ports[port] = type
         if not self.vlans.has_key(vlan):
             self.vlans[vlan] = []
         if not port in self.vlans[vlan]:
             self.vlans[vlan].append(port)
-            
+
         self.spinBoxPort.setValue(max(self.ports) + 1)
         self.treeWidgetPorts.resizeColumnToContents(0)
-        
+
     def slotDeletePort(self):
         """ Delete a port
         """
@@ -143,7 +154,7 @@ class Page_ETHSW(QtGui.QWidget, Ui_ETHSWPage):
         self.treeWidgetPorts.clear()
         self.vlans = {}
         self.ports = {}
-        
+
         for (vlan,  portlist) in ETHSWconfig['vlans'].iteritems():
             for port in portlist:
                 item = QtGui.QTreeWidgetItem(self.treeWidgetPorts)
@@ -164,7 +175,7 @@ class Page_ETHSW(QtGui.QWidget, Ui_ETHSWPage):
     def saveConfig(self, id, config = None):
         """ Save the config
         """
-    
+
         self.node = globals.GApp.topology.getNode(id)
         if config:
             ETHSWconfig = config
