@@ -20,9 +20,12 @@
 #
 
 from PyQt4 import QtCore, QtGui
+import GNS3.Globals as globals
 from GNS3.Utils import translate
-from GNS3.Node.DecorativeNode import DecorativeNode
 from GNS3.Globals.Symbols import SYMBOLS
+from GNS3.Node.IOSRouter import IOSRouter
+from GNS3.Node.AnyEmuDevice import QemuDevice, PIX, ASA, AWP, JunOS, IDS
+from GNS3.Node.AnyVBoxEmuDevice import VBoxDevice
 
 class nodesDock(QtGui.QTreeWidget):
     """ Class for managing the node types list
@@ -34,42 +37,17 @@ class nodesDock(QtGui.QTreeWidget):
         QtGui.QTreeWidget.__init__(self, parent)
         self.header().hide()
 
-    def populateNodeDock(self):
+    def populateNodeDock(self, nodeType):
         """ Fill the node dock
         """
 
         self.clear()
-        decorative_symbol_present = False
-        for symbol in SYMBOLS:
-            if symbol['object'] == DecorativeNode:
-                decorative_symbol_present = True
-                break
-        
-        parent_emulated_devices = self
-        parent_decorative_nodes = self
-
-        if decorative_symbol_present:
-        
-            parent_emulated_devices = QtGui.QTreeWidgetItem()
-            parent_emulated_devices.setText(0, translate('nodesDock', 'Emulated devices'))
-            parent_emulated_devices.setIcon(0,  QtGui.QIcon(':/icons/package.svg'))
-            parent_emulated_devices.setFlags(QtCore.Qt.ItemIsEnabled)
-            self.addTopLevelItem(parent_emulated_devices)
-            self.expandItem(parent_emulated_devices)
-            
-            parent_decorative_nodes = QtGui.QTreeWidgetItem()
-            parent_decorative_nodes.setText(0, translate('nodesDock', 'Decorative nodes'))
-            parent_decorative_nodes.setIcon(0,  QtGui.QIcon(':/icons/package.svg'))
-            parent_decorative_nodes.setFlags(QtCore.Qt.ItemIsEnabled)
-            self.addTopLevelItem(parent_decorative_nodes)
-            self.expandItem(parent_decorative_nodes)
-        
         count = 0
         for symbol in SYMBOLS:
-            if symbol['object'] == DecorativeNode:
-                item = QtGui.QTreeWidgetItem(parent_decorative_nodes, 1000 + count)
-            else:
-                item = QtGui.QTreeWidgetItem(parent_emulated_devices, 1000 + count)
+            if nodeType != 'All devices' and (not symbol.has_key('type') or symbol['type'] != nodeType):
+                count += 1
+                continue
+            item = QtGui.QTreeWidgetItem(self, 1000 + count)
             if symbol['translated']:
                 item.setText(0, translate("nodesDock", symbol['name']))
                 item.setData(0, QtCore.Qt.UserRole, QtCore.QVariant(symbol['name']))
@@ -77,6 +55,49 @@ class nodesDock(QtGui.QTreeWidget):
                 item.setText(0, symbol['name'])
             item.setIcon(0, QtGui.QIcon(symbol['normal_svg_file']))
             count += 1
+            
+            self.checkImageAvailability(item, symbol)
+
+    def checkImageAvailability(self, item, symbol):
+        """ Checks if the image of the associated device is registered/configured,
+             and if not disable it graphically so it can't be drag & drop'ed """
+
+        node = symbol['object']
+        item.setDisabled(symbol.has_key('checkForImage') and symbol['checkForImage'])
+
+        # Check if an IOS image is registered
+        if issubclass(node, IOSRouter):
+            if len(globals.GApp.iosimages.keys()) == 0:
+                return
+            # Check availability of each Cisco platform's image individually
+            for (image, conf) in globals.GApp.iosimages.iteritems():
+                # Special check for EtherSwitch router
+                if conf.platform in 'c3700' and symbol['name'] == 'EtherSwitch router':
+                    item.setDisabled(False)
+                    return
+                if conf.platform in symbol['name']:
+                    item.setDisabled(False)
+                    return
+        # Check if a JunOS image is registered
+        elif issubclass(node, JunOS) and len(globals.GApp.junosimages) != 0:
+            item.setDisabled(False)
+        # Check availability for firewall and IDS images
+        elif issubclass(node, ASA) and len(globals.GApp.asaimages) != 0:
+            item.setDisabled(False)
+        elif issubclass(node, AWP) and len(globals.GApp.awprouterimages) != 0:
+            item.setDisabled(False)
+        elif issubclass(node, PIX) and len(globals.GApp.piximages) != 0:
+            item.setDisabled(False)
+        elif issubclass(node, IDS) and len(globals.GApp.idsimages) != 0:
+            item.setDisabled(False)
+        # Check if an image for Qemu or VirtualBox is registered
+        elif issubclass(node, QemuDevice) and len(globals.GApp.qemuimages) != 0:
+            item.setDisabled(False)
+        elif issubclass(node, VBoxDevice) and len(globals.GApp.vboximages) != 0:
+            item.setDisabled(False)
+        # No need to register an image for a "Host" so enable it
+        elif symbol['name'] == 'Host':
+            item.setDisabled(False)
 
     def mouseMoveEvent(self, event):
         """ Drag event
@@ -120,4 +141,4 @@ class nodesDock(QtGui.QTreeWidget):
     def retranslateUi(self, MainWindow):
 
         self.populateNodeDock()
-
+        return
