@@ -16,7 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# code@gns3.net
+# http://www.gns3.net/contact
 #
 
 import GNS3.Globals as globals
@@ -61,14 +61,18 @@ class topologySummaryDock(QtGui.QTreeWidget):
                 list.append(interface)
                 list.append(neighbor[0].hostname)
                 list.append(neighbor[1])
+                list.append(hostname)
                 item.setData(0, QtCore.Qt.UserRole, QtCore.QVariant(list))
-                newText = unicode(translate('topologySummaryDock', '%s is connected to %s %s')) \
+                newText = translate('topologySummaryDock', '%s is connected to %s %s') \
                             % (interface, neighbor[0].hostname, neighbor[1])
                 item.setText(0, newText)
                 items.append(item)
             rootitem.addChildren(items)
             self.insertTopLevelItem(0, rootitem)
             self.sortByColumn(0, QtCore.Qt.AscendingOrder)
+        if self.expanded:
+            self.expandAll()
+        globals.GApp.mainWindow.capturesDock.refresh()
             
     def changeNodeStatus(self, hostname, status):
         """ Change the status of a node
@@ -88,14 +92,15 @@ class topologySummaryDock(QtGui.QTreeWidget):
                 item.setIcon(0, QtGui.QIcon(':/icons/led_red.svg'))
         if self.expanded:
             self.expandAll()
+        globals.GApp.mainWindow.capturesDock.refresh()
 
     def retranslateItem(self, item):
 
         # Translate current item
         data = item.data(0, QtCore.Qt.UserRole).toStringList()
 
-        if data.count() == 3:
-            newText = unicode(translate('topologySummaryDock', '%s is connected to %s %s')) \
+        if data.count() == 4:
+            newText = translate('topologySummaryDock', '%s is connected to %s %s') \
                         % (unicode(data[0]), unicode(data[1]), unicode(data[2]))
             item.setText(0, newText)
 
@@ -134,6 +139,21 @@ class topologySummaryDock(QtGui.QTreeWidget):
         self.connect(collapseAll, QtCore.SIGNAL('triggered()'), self.slotCollapseAll)
         menu.addAction(expandAll)
         menu.addAction(collapseAll)
+
+        # add link actions to menu if link info item is selected
+        curitem = self.currentItem()
+        if curitem:
+            menu.addSeparator()
+            data = curitem.data(0, QtCore.Qt.UserRole).toStringList()
+            if data.count() == 4:
+                node_interface = data[0]
+                node_hostname = data[3]
+                node = globals.GApp.topology.getNode(globals.GApp.topology.getNodeID(node_hostname))
+                if node:
+                    link = node.getConnectedLinkByName(node_interface)
+                    if link:
+                        link.addLinkActionsToMenu(menu)
+
         menu.exec_(QtGui.QCursor.pos())
 
     def slotExpandAll(self):
